@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2019 Bryan Siepert for Adafruit Industries
 #
-# Copyright (c) 2019 Bryan Siepert for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_mcp4728`
 ================================================================================
@@ -81,14 +64,19 @@ class Vref(CV):
     pass  # pylint: disable=unnecessary-pass
 
 
-Vref.add_values((("VDD", 0, "VDD", None), ("INTERNAL", 1, "Internal 2.048V", None),))
+Vref.add_values(
+    (
+        ("VDD", 0, "VDD", None),
+        ("INTERNAL", 1, "Internal 2.048V", None),
+    )
+)
 
 
 class MCP4728:
     """Helper library for the Microchip MCP4728 I2C 12-bit Quad DAC.
 
-        :param ~busio.I2C i2c_bus: The I2C bus the MCP4728 is connected to.
-        :param address: The I2C slave address of the sensor
+    :param ~busio.I2C i2c_bus: The I2C bus the MCP4728 is connected to.
+    :param address: The I2C slave address of the sensor
 
     """
 
@@ -135,7 +123,7 @@ class MCP4728:
 
     def save_settings(self):
         """Saves the currently selected values, Vref, and gain selections for each channel
-           to the EEPROM, setting them as defaults on power up"""
+        to the EEPROM, setting them as defaults on power up"""
         byte_list = []
         byte_list += self._generate_bytes_with_flags(self.channel_a)
         byte_list += self._generate_bytes_with_flags(self.channel_b)
